<!DOCTYPE TS><TS>
<context>
    <name>ArtefactAction</name>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>AskCost</name>
    <message>
        <source>Change</source>
        <translation>Cambia</translation>
    </message>
</context>
<context>
    <name>AskDiversificationList</name>
    <message>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>BuildingAction</name>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>DecorationEffect</name>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>DialogArtefactAction</name>
    <message>
        <source>Action type: </source>
        <translation>Tipo di azione:</translation>
    </message>
    <message>
        <source>Characteristic</source>
        <translation>Caratteristica</translation>
    </message>
    <message>
        <source>Spell</source>
        <translation>Sortilegio</translation>
    </message>
    <message>
        <source>Fixed value</source>
        <translation>Valore</translation>
    </message>
    <message>
        <source>Ratio</source>
        <translation>Percentuale</translation>
    </message>
    <message>
        <source>Modification type: </source>
        <translation>Tasso di modifica:</translation>
    </message>
    <message>
        <source>Parameter: </source>
        <translation>Parametro:</translation>
    </message>
    <message>
        <source>Value: </source>
        <translation>Valore:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>DialogBuildingAction</name>
    <message>
        <source>Action type: </source>
        <translation>Tipo di azione:</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>First Time</source>
        <translation>Prima volta</translation>
    </message>
    <message>
        <source>First Time Lord</source>
        <translation>Prima volta signore</translation>
    </message>
    <message>
        <source>Next Time</source>
        <translation>Prossima volta</translation>
    </message>
    <message>
        <source>Attack</source>
        <translation>Attacco</translation>
    </message>
    <message>
        <source>Defense</source>
        <translation>Difesa</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Potere</translation>
    </message>
    <message>
        <source>Knowledge</source>
        <translation>Conoscenza</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Movimento</translation>
    </message>
    <message>
        <source>Maxmove</source>
        <translation>Movimento max</translation>
    </message>
    <message>
        <source>TechPoint</source>
        <translation>Punti di tecnica</translation>
    </message>
    <message>
        <source>MaxTechPoint</source>
        <translation>Max. Punti di tecnica</translation>
    </message>
    <message>
        <source>Morale</source>
        <translation>Morale</translation>
    </message>
    <message>
        <source>Luck</source>
        <translation>Fortuna</translation>
    </message>
    <message>
        <source>Vision</source>
        <translation>Visione</translation>
    </message>
    <message>
        <source>Experience</source>
        <translation>Esperienza</translation>
    </message>
    <message>
        <source>Skill</source>
        <translation>Abilità</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Artefatto</translation>
    </message>
    <message>
        <source>Unit</source>
        <translation>Unità</translation>
    </message>
    <message>
        <source>Resource</source>
        <translation>Risorsa</translation>
    </message>
    <message>
        <source>Random Resource</source>
        <translation>Risorsa casuale</translation>
    </message>
    <message>
        <source>Elementary Action: </source>
        <translation>Azione elementare:</translation>
    </message>
    <message>
        <source>Param: </source>
        <translation>Parametro:</translation>
    </message>
    <message>
        <source>Coeff: </source>
        <translation>Coeff:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>DialogEffect</name>
    <message>
        <source>Effect type: </source>
        <translation>Tipo di effetto:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Effect value: </source>
        <translation>Valore dell&apos;effetto:</translation>
    </message>
</context>
<context>
    <name>EditCost</name>
    <message>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>EditCreature</name>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Attack: </source>
        <translation>Attacco:</translation>
    </message>
    <message>
        <source>Defense: </source>
        <translation>Difesa:</translation>
    </message>
    <message>
        <source>Max Health: </source>
        <translation>Punti vita max.:</translation>
    </message>
    <message>
        <source>Max Move: </source>
        <translation>Movimento max.:</translation>
    </message>
    <message>
        <source>Dist Attack: </source>
        <translation>Attacco a distanza:</translation>
    </message>
    <message>
        <source>Min Damages: </source>
        <translation>Danni minimi:</translation>
    </message>
    <message>
        <source>Max Damages: </source>
        <translation>Danni massimi:</translation>
    </message>
    <message>
        <source>Morale: </source>
        <translation>Morale:</translation>
    </message>
    <message>
        <source>Luck: </source>
        <translation>Fortuna:</translation>
    </message>
    <message>
        <source>Size: </source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <source>Cost: </source>
        <translation>Costo:</translation>
    </message>
    <message>
        <source>Maintenance cost: </source>
        <translation>Costo di mantenimento:</translation>
    </message>
    <message>
        <source>Picture: </source>
        <translation>Immagine:</translation>
    </message>
    <message>
        <source>X Offset: </source>
        <translation>Scostamento X:</translation>
    </message>
    <message>
        <source>Y Offset: </source>
        <translation>Scostamento Y:</translation>
    </message>
</context>
<context>
    <name>EditTroop</name>
    <message>
        <source>Race : </source>
        <translation>Specie:</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Number : </source>
        <translation>Numero:</translation>
    </message>
</context>
<context>
    <name>MapDispositionEditor</name>
    <message>
        <source>Free</source>
        <translation>Libero</translation>
    </message>
    <message>
        <source>Occupied</source>
        <translation>Occupato</translation>
    </message>
    <message>
        <source>Door</source>
        <translation>Entrata</translation>
    </message>
    <message>
        <source>Columns:</source>
        <translation>Colonne:</translation>
    </message>
    <message>
        <source>Rows:</source>
        <translation>Righe:</translation>
    </message>
</context>
<context>
    <name>PreviewBaseDialog</name>
    <message>
        <source>Buildings</source>
        <translation>Edifici</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Effect &apos;</source>
        <translation>Effetto &apos;</translation>
    </message>
    <message>
        <source>&apos; with param </source>
        <translation>&apos; con parametro </translation>
    </message>
    <message>
        <source>Action: </source>
        <translation>Azione:</translation>
    </message>
    <message>
        <source>Charac </source>
        <translation>Caratteristica </translation>
    </message>
    <message>
        <source>Spell </source>
        <translation>Sortilegio</translation>
    </message>
    <message>
        <source> modify by </source>
        <translation> modificata di </translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source> elementary </source>
        <translation> elementare </translation>
    </message>
</context>
<context>
    <name>SectionArtefact</name>
    <message>
        <source>Artefact</source>
        <translation>Artefatto</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Position: </source>
        <translation>Posizione:</translation>
    </message>
    <message>
        <source>Icon: </source>
        <translation>Icona:</translation>
    </message>
    <message>
        <source>Item: </source>
        <translation>Oggetto:</translation>
    </message>
</context>
<context>
    <name>SectionBase</name>
    <message>
        <source> Base </source>
        <translation>Castello</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Population: </source>
        <translation>Popolazione:</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Anteprima</translation>
    </message>
    <message>
        <source> Base : %d/%d</source>
        <translation>Castello: %d/%d</translation>
    </message>
    <message>
        <source>Res Cost: </source>
        <translation>Costo ris:</translation>
    </message>
    <message>
        <source>Growth: </source>
        <translation>Crescita:</translation>
    </message>
    <message>
        <source>Loss: </source>
        <translation>Diminuzione:</translation>
    </message>
    <message>
        <source>Preview inside</source>
        <translation>Anteprima interno</translation>
    </message>
</context>
<context>
    <name>SectionBuilding</name>
    <message>
        <source>Building</source>
        <translation>Edificio</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Descrizione:</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Picture: </source>
        <translation>Immagine:</translation>
    </message>
    <message>
        <source>Number Frames: </source>
        <translation>Numero di frame:</translation>
    </message>
    <message>
        <source>Animation Freq.: </source>
        <translation>Frequenza di animazione:</translation>
    </message>
</context>
<context>
    <name>SectionCreature</name>
    <message>
        <source>Race</source>
        <translation>Specie</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source> Creature </source>
        <translation>Creatura</translation>
    </message>
    <message>
        <source> Race : %d/%d</source>
        <translation>Specie: %d/%d</translation>
    </message>
    <message>
        <source> Creature : %d/%d</source>
        <translation>Creatura: %d/%d</translation>
    </message>
    <message>
        <source> Creature : %d/??</source>
        <translation>Creatura: %d/??</translation>
    </message>
</context>
<context>
    <name>SectionDecoration</name>
    <message>
        <source>Decoration</source>
        <translation type="obsolete">Decorazione</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Info: </source>
        <translation>Informazioni:</translation>
    </message>
    <message>
        <source>Image: </source>
        <translation>Immagine:</translation>
    </message>
    <message>
        <source>Decoration group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decoration item</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionExperience</name>
    <message>
        <source>List of required experience to gain for accessing the next level:</source>
        <translation>Lista di punti esperienza richiesti per accedere al livello successivo:</translation>
    </message>
</context>
<context>
    <name>SectionGeneral</name>
    <message>
        <source>Fog of war</source>
        <translation type="obsolete">Nebbia di guerra</translation>
    </message>
    <message>
        <source>Number of unit/lord</source>
        <translation>Numero di unità/signori</translation>
    </message>
    <message>
        <source>Logo (200x180): </source>
        <translation>Logo (200x180): </translation>
    </message>
    <message>
        <source>Vision management: </source>
        <translation>Gestione della vista:</translation>
    </message>
</context>
<context>
    <name>SectionGround</name>
    <message>
        <source>Tiles</source>
        <translation>Suoli</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Coef: </source>
        <translation>Coefficiente:</translation>
    </message>
    <message>
        <source>Color: </source>
        <translation>Colore:</translation>
    </message>
    <message>
        <source>Tile </source>
        <translation>Suolo</translation>
    </message>
</context>
<context>
    <name>SectionInsideBuilding</name>
    <message>
        <source> Building </source>
        <translation>Edificio</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Descrizione:</translation>
    </message>
    <message>
        <source>Cost: </source>
        <translation>Costo:</translation>
    </message>
    <message>
        <source>Maintenance cost: </source>
        <translation>Costo di mantenimento:</translation>
    </message>
    <message>
        <source> Building : %d/%d</source>
        <translation>Edificio : %d/%d</translation>
    </message>
    <message>
        <source>Action: </source>
        <translation type="obsolete">Azione:</translation>
    </message>
    <message>
        <source>Params: </source>
        <translation>Parametri:</translation>
    </message>
    <message>
        <source>Not yet used</source>
        <translation>Non ancora usato</translation>
    </message>
    <message>
        <source>Main Building</source>
        <translation>Edificio principale</translation>
    </message>
    <message>
        <source>Castle</source>
        <translation>Castello</translation>
    </message>
    <message>
        <source>Prod Creature</source>
        <translation>Produce Creature</translation>
    </message>
    <message>
        <source>Market</source>
        <translation>Mercato</translation>
    </message>
</context>
<context>
    <name>SectionLord</name>
    <message>
        <source>Lord</source>
        <translation>Signore</translation>
    </message>
    <message>
        <source>Photo: </source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Icon: </source>
        <translation>Icona:</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Category : </source>
        <translation>Categoria:</translation>
    </message>
    <message>
        <source>Race : </source>
        <translation type="obsolete">Specie:</translation>
    </message>
    <message>
        <source>Attack : </source>
        <translation>Attacco :</translation>
    </message>
    <message>
        <source>Defense : </source>
        <translation>Difesa:</translation>
    </message>
    <message>
        <source>Power : </source>
        <translation>Potere :</translation>
    </message>
    <message>
        <source>Knowledge : </source>
        <translation>Conoscenza :</translation>
    </message>
    <message>
        <source>MaxMoves : </source>
        <translation>Movimento max.:</translation>
    </message>
    <message>
        <source>Vision : </source>
        <translation>Visione :</translation>
    </message>
    <message>
        <source> (Race: </source>
        <translation>(Specie:</translation>
    </message>
</context>
<context>
    <name>SectionLordCategory</name>
    <message>
        <source>Lord Categories</source>
        <translation>Categorie dei signori</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Descrizione:</translation>
    </message>
    <message>
        <source>Race: </source>
        <translation>Specie:</translation>
    </message>
    <message>
        <source>Evolution of Attack skill (weight): </source>
        <translation>Evoluzione dell&apos;abilità attacco (peso):</translation>
    </message>
    <message>
        <source>Evolution of Defense skill (weight): </source>
        <translation>Evoluzione dell&apos;abilità difesa (peso):</translation>
    </message>
    <message>
        <source>Evolution of Power skill (weight): </source>
        <translation>Evoluzione dell&apos;abilità potere (peso):</translation>
    </message>
    <message>
        <source>Evolution of Knowledge skill (weight): </source>
        <translation>Evoluzione dell&apos;abilità conoscenza (peso):</translation>
    </message>
</context>
<context>
    <name>SectionMachine</name>
    <message>
        <source>War Machine</source>
        <translation>Macchina da guerra</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Param (1): </source>
        <translation>Parametro (1):</translation>
    </message>
    <message>
        <source>Params: </source>
        <translation>Parametri:</translation>
    </message>
    <message>
        <source>Icon: </source>
        <translation>Icona:</translation>
    </message>
    <message>
        <source>Item: </source>
        <translation>Oggetto:</translation>
    </message>
</context>
<context>
    <name>SectionRessource</name>
    <message>
        <source>Ressource</source>
        <translation>Risorsa</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Icon: </source>
        <translation>Icona:</translation>
    </message>
    <message>
        <source>Small icon: </source>
        <translation>Piccola icona:</translation>
    </message>
</context>
<context>
    <name>SectionSelector</name>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Artefacts</source>
        <translation>Artefatti</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Squadre</translation>
    </message>
    <message>
        <source>Bases</source>
        <translation>Castelli</translation>
    </message>
    <message>
        <source>Buildings</source>
        <translation>Edifici</translation>
    </message>
    <message>
        <source>Creatures</source>
        <translation>Creature</translation>
    </message>
    <message>
        <source>Decorations</source>
        <translation>Decorazioni</translation>
    </message>
    <message>
        <source>Grounds</source>
        <translation>Terreni</translation>
    </message>
    <message>
        <source>Lords</source>
        <translation>Signori</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Risorse</translation>
    </message>
    <message>
        <source>War Machines</source>
        <translation>Macchine da guerra</translation>
    </message>
    <message>
        <source>Lord Categories</source>
        <translation>Categorie dei signori</translation>
    </message>
    <message>
        <source>Levels</source>
        <translation>Livelli</translation>
    </message>
</context>
<context>
    <name>SectionTeam</name>
    <message>
        <source>Team</source>
        <translation>Squadra</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Colore</translation>
    </message>
    <message>
        <source>Flag: </source>
        <translation>Bandiera:</translation>
    </message>
</context>
<context>
    <name>SelectionWidget</name>
    <message>
        <source>None</source>
        <translation>Niente</translation>
    </message>
</context>
<context>
    <name>ThemeInterface</name>
    <message>
        <source>Theme editor for &apos;Attal - Lords of Doom&apos;</source>
        <translation>Editor di temi per &apos;Attal - Signori del Destino&apos;</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barra di stato</translation>
    </message>
    <message>
        <source>New theme</source>
        <translation>Nuovo tema</translation>
    </message>
    <message>
        <source>Open theme</source>
        <translation>Apri tema</translation>
    </message>
    <message>
        <source>Save theme</source>
        <translation>Salva tema</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>&amp;New theme</source>
        <translation>&amp;Nuovo tema</translation>
    </message>
    <message>
        <source>CTRL+N</source>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <source>&amp;Open theme</source>
        <translation>&amp;Apri tema</translation>
    </message>
    <message>
        <source>CTRL+O</source>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <source>&amp;Save theme</source>
        <translation>&amp;Salva tema</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Non posso caricare il tema</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Il tema </translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation> non è stato caricato con successo</translation>
    </message>
</context>
</TS>
